@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.040';
+our $VERSION = '0.041';
 
 use base qw{Astro::Coord::ECI};
 
@@ -490,7 +490,7 @@ eod
 
 #	Coordinates of Moon (finally!)
 
-    my $lambda = mod2pi( deg2rad ($sigmal / 1_000_000) + $Lprime );
+    my $lambda = deg2rad ($sigmal / 1_000_000) + $Lprime;
     my $beta = deg2rad ($sigmab / 1_000_000);
     my $delta = $sigmar / 1000 + 385_000.56;
 
@@ -498,7 +498,7 @@ eod
 
     $lambda += nutation_in_longitude ($time);
 
-    $self->ecliptic ($beta, $lambda, $delta);
+    $self->ecliptic ($beta, mod2pi( $lambda ), $delta);
     ## $self->set (equinox_dynamical => $time);
     $self->equinox_dynamical ($time);
     return $self;
